@@ -274,7 +274,6 @@ COUNTRY_DETAILS = {
         'id': 15,
         'legacy': 'ME',
         'mcc': 297,
-        'ratingsbody': 'ESRB',
         'slug': 'me',
         'special': False,
         'weight': 0
@@ -315,6 +314,18 @@ COUNTRY_DETAILS = {
         'special': False,
         'weight': 0
     },
+    'PHL': {
+        'adolescent': True,
+        'default_currency': 'PHP',
+        'default_language': 'en',
+        'id': 35,
+        'legacy': 'PH',
+        'low_memory': True,
+        'mcc': 515,
+        'ratingsbody': None,
+        'slug': 'ph',
+        'weight': 0
+    },
     'POL': {
         'adolescent': True,
         'default_currency': 'PLN',
@@ -327,6 +338,17 @@ COUNTRY_DETAILS = {
         'special': False,
         'weight': 0
     },
+    'RUS': {
+        'adolescent': True,
+        'default_currency': 'EUR',
+        'default_language': 'ru',
+        'id': 36,
+        'legacy': 'RU',
+        'mcc': 250,
+        'slug': 'ru',
+        'special': False,
+        'weight': 0
+    },
     'SLV': {
         'adolescent': True,
         'default_currency': 'USD',
